CompactTweetView class

Inheritance

Constructors

CompactTweetView(TweetVM _tweetVM, {TextStyle? userNameStyle, TextStyle? userScreenNameStyle, TextStyle? textStyle, TextStyle? clickableTextStyle, TextStyle? retweetInformationTextStyle, TextStyle? quoteUserNameStyle, TextStyle? quoteUserScreenNameStyle, TextStyle? quoteTextStyle, TextStyle? quoteClickableTextStyle, Color? quoteBorderColor, Color? quoteBackgroundColor, Color? backgroundColor, double? videoPlayerInitialVolume, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, required bool videoHighQuality, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})
CompactTweetView.fromTweetV1(TweetV1Response tweet, {TextStyle? userNameStyle = defaultCompactUserNameStyle, TextStyle? userScreenNameStyle = defaultCompactUserScreenNameStyle, TextStyle? textStyle = defaultCompactTextStyle, TextStyle? clickableTextStyle = defaultCompactClickableTextStyle, TextStyle? retweetInformationTextStyle = defaultCompactRetweetInformationNameStyle, TextStyle? quoteUserNameStyle = defaultQuoteUserNameStyle, TextStyle? quoteUserScreenNameStyle = defaultQuoteUserScreenNameStyle, TextStyle? quoteTextStyle = defaultQuoteTextStyle, TextStyle? quoteClickableTextStyle = defaultQuoteClickableTextStyle, Color? quoteBorderColor = Colors.grey, Color? quoteBackgroundColor = Colors.white, Color? backgroundColor = Colors.white, double? videoPlayerInitialVolume = 0.0, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, bool videoHighQuality = true, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})
CompactTweetView.fromTweetV2(TweetV2Response tweet, {TextStyle? userNameStyle = defaultCompactUserNameStyle, TextStyle? userScreenNameStyle = defaultCompactUserScreenNameStyle, TextStyle? textStyle = defaultCompactTextStyle, TextStyle? clickableTextStyle = defaultCompactClickableTextStyle, TextStyle? retweetInformationTextStyle = defaultCompactRetweetInformationNameStyle, TextStyle? quoteUserNameStyle = defaultQuoteUserNameStyle, TextStyle? quoteUserScreenNameStyle = defaultQuoteUserScreenNameStyle, TextStyle? quoteTextStyle = defaultQuoteTextStyle, TextStyle? quoteClickableTextStyle = defaultQuoteClickableTextStyle, Color? quoteBorderColor = Colors.grey, Color? quoteBackgroundColor = Colors.white, Color? backgroundColor = Colors.white, double? videoPlayerInitialVolume = 0.0, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, bool videoHighQuality = true, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})

Properties

autoPlayVideo → bool?
If set to true the video in the tweet, if available, will autoplay By default it is false
final
backgroundColor → Color?
Color of the Tweet background
final
clickableTextStyle → TextStyle?
Style of the clickable elements in the Tweet text (URLs, mentions, hashtags, symbols)
final
createdDateDisplayFormat → DateFormat?
Date format when the tweet was created. When null it defaults to DateFormat("HH:mm • MM.dd.yyyy", 'en_US')
final
enableVideoFullscreen → bool?
If set to false will disallow user to enter full screen in tweet video By default it is true
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTapImage → OnTapImage?
Function used when you want a custom image tapped callback
final
quoteBackgroundColor → Color?
Color of the embedded quote Tweet background
final
quoteBorderColor → Color?
Color of the border around embedded quote Tweet
final
quoteClickableTextStyle → TextStyle?
Style of the clickable elements in the Tweet text (URLs, mentions, hashtags, symbols) in a embedded quote Tweet
final
quoteTextStyle → TextStyle?
Style of the Tweet text in a embedded quote Tweet
final
quoteUserNameStyle → TextStyle?
Style of the user name in a embedded quote Tweet
final
quoteUserScreenNameStyle → TextStyle?
Style of the '@' user name and the date of the Tweet in a embedded quote Tweet
final
retweetInformationTextStyle → TextStyle?
Style of the retweet information
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
Style of the Tweet text
final
userNameStyle → TextStyle?
Style of the user name
final
userScreenNameStyle → TextStyle?
Style of the '@' user name and the date of the Tweet
final
videoControlBarBgColor → Color?
Set video Control Bar background color
final
videoHighQuality → bool
If set to true betterplayer will load the highest quality available. If set to false betterplayer will load the lowest quality available.
final
videoPlaceholder → Widget?
The placeholder is displayed underneath the Video before it is initialized or played.
final
videoPlayerInitialVolume → double?
If the Tweet contains a video then an initial volume can be specified with a value between 0.0 and 1.0.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited