EmbeddedTweetView class

Inheritance

Constructors

EmbeddedTweetView(TweetVM _tweetVM, {Color? backgroundColor, required bool darkMode, double? videoPlayerInitialVolume, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, required bool videoHighQuality, bool showRepliesCount = false, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})
EmbeddedTweetView.fromTweetV1(TweetV1Response tweet, {Color? backgroundColor = Colors.white, bool darkMode = false, double? videoPlayerInitialVolume = 0.0, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, bool videoHighQuality = true, bool showRepliesCount = false, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})
EmbeddedTweetView.fromTweetV2(TweetV2Response tweet, {Color? backgroundColor = Colors.white, bool darkMode = false, double? videoPlayerInitialVolume = 0.0, OnTapImage? onTapImage, DateFormat? createdDateDisplayFormat, bool videoHighQuality = true, bool showRepliesCount = false, bool? autoPlayVideo, bool? enableVideoFullscreen, Color? videoControlBarBgColor, Widget? videoPlaceholder})

Properties

autoPlayVideo → bool?
If set to true the video in the tweet, if available, will autoplay By default it is false
final
backgroundColor → Color?
Background color for the container
final
createdDateDisplayFormat → DateFormat?
Date format when the tweet was created. When null it defaults to DateFormat("HH:mm • MM.dd.yyyy", 'en_US')
final
darkMode → bool
If set to true the the text and icons will be light
final
enableVideoFullscreen → bool?
If set to false will disallow user to enter full screen in tweet video By default it is true
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTapImage → OnTapImage?
Function used when you want a custom image tapped callback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showRepliesCount → bool
If set to true, the number of replies on a tweet will be displayed
final
videoControlBarBgColor → Color?
Set video Control Bar background color
final
videoHighQuality → bool
If set to true betterplayer will load the highest quality available. If set to false betterplayer will load the lowest quality available.
final
videoPlaceholder → Widget?
The placeholder is displayed underneath the Video before it is initialized or played.
final
videoPlayerInitialVolume → double?
If the Tweet contains a video then an initial volume can be specified with a value between 0.0 and 1.0.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited