UrlEntity class

Represents URLs included in the text of a Tweet or within textual fields of a user object.

Inheritance
Implementers

Constructors

UrlEntity({required String url, required String expandedUrl, required String displayUrl, required dynamic indices})
UrlEntity.fromJson(Map<String, dynamic> json)
factory
UrlEntity.fromRawJson(String str)
factory

Properties

displayUrl ↔ String
URL pasted/typed into Tweet.
getter/setter pair
end → int
no setterinherited
expandedUrl ↔ String
Expanded version of display_url .
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indices ↔ List<int>
An array of integers indicating the offsets within the Tweet text where the Entity begins and ends.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
no setterinherited
url ↔ String
Wrapped URL, corresponding to the value embedded directly into the raw Tweet text, and the values for the indices parameter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited