User class

Users can be anyone or anything. They tweet, follow, create lists, have a home_timeline, can be mentioned, and can be looked up in bulk.

Constructors

User({required double id, required String name, required String screenName, required bool verified, String? profileImageUrlHttps})
User.fromJson(Map<String, dynamic> json)
factory
User.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ double
The integer representation of the unique identifier for this User. This number is greater than 53 bits and some programming languages may have difficulty/silent defects in interpreting it. Using a signed 64 bit integer for storing this identifier is safe. Use id_str for fetching the identifier to stay on the safe side. See Twitter IDs, JSON and Snowflake .
getter/setter pair
name ↔ String
The name of the user, as they’ve defined it. Not necessarily a person’s name. Typically capped at 50 characters, but subject to change.
getter/setter pair
profileImageUrlHttps ↔ String?
A HTTPS-based URL pointing to the user’s profile image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenName ↔ String
The screen name, handle, or alias that this user identifies themselves with. screen_names are unique but subject to change. Use id_str as a user identifier whenever possible. Typically a maximum of 15 characters long, but some historical accounts may exist with longer names.
getter/setter pair
verified ↔ bool
When true, indicates that the user has a verified account. See Verified Accounts
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited