TweetVM class

Available extensions

Constructors

TweetVM({required String? createdAt, required bool hasSupportedVideo, required List<Entity> allEntities, required bool hasPhoto, required bool hasGif, required String tweetLink, required String userLink, required String text, required Runes textRunes, required String? profileUrl, required List<String> allPhotos, required String userName, required String userScreenName, TweetVM? quotedTweet, TweetVM? retweetedTweet, required bool userVerified, String? videoPlaceholderUrl, required Map<String, String> videoUrls, double? videoAspectRatio, int? favoriteCount, int? repliesCount, int? startDisplayText, int? endDisplayText, required bool favorited, required bool replied})
const
TweetVM.fromApiModel(TweetV1Response tweet, DateFormat? createdDateDisplayFormat)
factory
TweetVM.fromApiV2Model(TweetV2Response tweetResponse, DateFormat? createdDateDisplayFormat)
factory

Properties

allEntities → List<Entity>
final
allPhotos → List<String>
final
createdAt → String?
final
endDisplayText → int?
final
favoriteCount → int?
final
favorited → bool
final
hasGif → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasPhoto → bool
final
hasSupportedVideo → bool
final
profileUrl → String?
final
quotedTweet → TweetVM?
final
replied → bool
final
repliesCount → int?
final
retweetedTweet → TweetVM?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDisplayText → int?
final
text → String
final
textRunes → Runes
final
final
final
userName → String
final
userScreenName → String
final
userVerified → bool
final
videoAspectRatio → double?
final
videoPlaceholderUrl → String?
final
videoUrls → Map<String, String>
final

Methods

getDisplayTweet() → TweetVM

Available on TweetVM, provided by the ExtendedText extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited